@@ -143,13 +143,10 @@ class Code:
         bare_repo = project_dir / "source.git"
         working_repo = project_dir / "working"
         repo = warez.Repo(bare_repo, init=True, bare=True)
-        print("A")
         repo.update_server_info()
-        print("B")
         repo.config("http.receivepack", "true")
-        print("C")
-        # TODO chgrp www-data source.git -R
-        # TODO chmod 775 source.git -R
+        subprocess.run(["sudo", "chgrp", "www-data", bare_repo, "-R"])
+        subprocess.run(["sudo", "chmod", "775", bare_repo, "-R"])
         warez.clone_repo(bare_repo, working_repo)  # TODO shallow?
         return web.Created(app.view.project_created(project), f"/{project}")
 
